==> gradle-2.6-rc-1-all.zip: gradle-2.6-rc-1/src/resources-http/org/gradle/internal/resource/transport/http/HttpResourceUploader.java <==
/*
 * Copyright 2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.resource.transport.http;

import org.apache.http.HttpResponse;
import org.apache.http.client.methods.HttpPut;
import org.apache.http.entity.ContentType;
import org.apache.http.util.EntityUtils;
import org.gradle.internal.resource.local.LocalResource;
import org.gradle.internal.resource.transfer.ExternalResourceUploader;

import java.io.IOException;
import java.net.URI;

public class HttpResourceUploader implements ExternalResourceUploader {

    private final HttpClientHelper http;

    public HttpResourceUploader(HttpClientHelper http) {
        this.http = http;
    }

    public void upload(LocalResource resource, URI destination) throws IOException {
        HttpPut method = new HttpPut(destination);
        final RepeatableInputStreamEntity entity = new RepeatableInputStreamEntity(resource, ContentType.APPLICATION_OCTET_STREAM);
        method.setEntity(entity);
        HttpResponse response = http.performHttpRequest(method);
        EntityUtils.consume(response.getEntity());
        if (!http.wasSuccessful(response)) {
            throw new IOException(String.format("Could not PUT '%s'. Received status code %s from server: %s",
                    destination, response.getStatusLine().getStatusCode(), response.getStatusLine().getReasonPhrase()));
        }

    }
}

==> gradle-3.2-rc-2-all.zip: gradle-3.2-rc-2/src/resources-http/org/gradle/internal/resource/transport/http/HttpResourceUploader.java <==
/*
 * Copyright 2012 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.gradle.internal.resource.transport.http;

import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPut;
import org.apache.http.client.utils.HttpClientUtils;
import org.apache.http.entity.ContentType;
import org.gradle.internal.resource.local.LocalResource;
import org.gradle.internal.resource.transfer.ExternalResourceUploader;

import java.io.IOException;
import java.net.URI;

public class HttpResourceUploader implements ExternalResourceUploader {

    private final HttpClientHelper http;

    public HttpResourceUploader(HttpClientHelper http) {
        this.http = http;
    }

    public void upload(LocalResource resource, URI destination) throws IOException {
        HttpPut method = new HttpPut(destination);
        final RepeatableInputStreamEntity entity = new RepeatableInputStreamEntity(resource, ContentType.APPLICATION_OCTET_STREAM);
        method.setEntity(entity);
        CloseableHttpResponse response = null;
        try {
            response = http.performHttpRequest(method);
            if (!http.wasSuccessful(response)) {
                throw new IOException(String.format("Could not PUT '%s'. Received status code %s from server: %s",
                    destination, response.getStatusLine().getStatusCode(), response.getStatusLine().getReasonPhrase()));
            }
        } finally {
            HttpClientUtils.closeQuietly(response);
        }
    }
}
